ATTENDED_APPT = "attended"
CANCELLED_APPT = "cancelled"
COMPLETE_APPT = "done"
INCOMPLETE_APPT = "incomplete"
IN_PROGRESS_APPT = "in_progress"
LAST_MONTH = "last_month"
EXTENDED_APPT = "extended"
MISSED_APPT = "missed"
NEW_APPT = "new"
NEXT_MONTH = "next_month"
ONTIME_APPT = "ontime"
SCHEDULED_APPT = "scheduled"
SKIPPED_APPT = "skipped"
UNSCHEDULED_APPT = "unscheduled"

INVALID_APPT_DATE = "invalid_appt_datetime"
INVALID_APPT_STATUS = "invalid_appt_status"
INVALID_APPT_REASON = "invalid_appt_reason"
INVALID_PREVIOUS_APPOINTMENT_NOT_UPDATED = "previous_appointment_not_updated"
INVALID_PREVIOUS_VISIT_MISSING = "previous_visit_missing"
INVALID_MISSED_APPT_NOT_ALLOWED = "invalid_missed_appt_not_allowed"
INVALID_APPT_STATUS_AT_BASELINE = "invalid_appt_status_at_baseline"
INVALID_SKIPPED_APPT_NOT_ALLOWED_AT_BASELINE = "invalid_skipped_appt_not_allowed_at_baseline"
INVALID_APPT_TIMING = "invalid_appt_timing"
INVALID_APPT_TIMING_CRFS_EXIST = "invalid_appt_timing_crfs_exist"
INVALID_APPT_TIMING_REQUISITIONS_EXIST = "invalid_appt_timing_requisitions_exist"

LT_30_DAYS = "LT_30_DAYS"
GTE_30_TO_60_DAYS = "GTE_30_TO_60_DAYS"
GTE_60_TO_90_DAYS = "GTE_60_TO_90_DAYS"
GTE_90_TO_180_DAYS = "GTE_90_TO_180_DAYS"
GTE_180 = "GTE_180"
