class HolidayError(Exception):
    pass


class HolidayImportError(Exception):
    pass


class HolidayFileNotFoundError(Exception):
    pass


class FacilityError(Exception):
    pass


class FacilitySiteError(Exception):
    pass


class FacilityCountryError(Exception):
    pass
