# Generated by Django 4.1.2 on 2022-11-30 01:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_sites", "0005_auto_20210423_1451"),
    ]

    operations = [
        migrations.AddField(
            model_name="siteprofile",
            name="languages",
            field=models.TextField(null=True),
        ),
    ]
