# group names
QA_REPORTS = "QA_REPORTS"
QA_REPORTS_AUDIT = "QA_REPORTS_AUDIT"

# role names
QA_REPORTS_ROLE = "qa_reports_role"
QA_REPORTS_SUPER_ROLE = "qa_reports_super_role"
QA_REPORTS_AUDIT_ROLE = "qa_reports_audit_role"

qa_reports_codenames = [
    "edc_qareports.add_note",
    "edc_qareports.change_note",
    "edc_qareports.delete_note",
    "edc_qareports.view_note",
    "edc_qareports.view_historicalnote",
    "edc_qareports.viewallsites_note",
    "edc_qareports.view_qareportlog",
    "edc_qareports.viewallsites_qareportlog",
    "edc_qareports.view_qareportlogsummary",
    "edc_qareports.viewallsites_qareportlogsummary",
]
