# Generated by Django 5.1.2 on 2024-11-16 17:32

from decimal import Decimal

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0030_remove_historicalrepackrequest_processed_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrepackrequest",
            name="task_id",
            field=models.UUIDField(null=True),
        ),
        migrations.AddField(
            model_name="repackrequest",
            name="task_id",
            field=models.UUIDField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="processed_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Containers processed",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="requested_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                validators=[django.core.validators.MinValueValidator(Decimal("0.0"))],
                verbose_name="Containers requested",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="processed_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Containers processed",
            ),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="requested_qty",
            field=models.DecimalField(
                decimal_places=2,
                max_digits=20,
                null=True,
                validators=[django.core.validators.MinValueValidator(Decimal("0.0"))],
                verbose_name="Containers requested",
            ),
        ),
    ]
