# Generated by Django 6.0 on 2026-01-19 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0103_auto_20260119_1945"),
    ]

    operations = [
        migrations.AddField(
            model_name="allocation",
            name="subject_identifier",
            field=models.CharField(
                blank=True, default="", editable=False, max_length=50
            ),
        ),
        migrations.AddField(
            model_name="historicalallocation",
            name="subject_identifier",
            field=models.CharField(
                blank=True, default="", editable=False, max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="subject_identifier",
            field=models.CharField(
                blank=True, default="", editable=False, max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="subject_identifier",
            field=models.CharField(
                blank=True, default="", editable=False, max_length=50
            ),
        ),
    ]
