from clinicedc_constants import OTHER

list_data = {
    "edc_refusal.refusalreasons": [
        ("unwilling_to_say", "I am unwilling to say"),
        ("dont_have_time", "I don't have time"),
        ("stigma", "I am worried about stigma"),
        ("must_consult_spouse", "I need to consult my spouse"),
        ("dont_want_medication", "I don't want to take any more medication"),
        ("dont_want_to_join", "I don't want to take part"),
        ("no_clinic_time", "I don't want to spend a lot of time at the clinic"),
        ("need_to_think_about_it", "I haven't had a chance to think about it"),
        ("moving", "I am moving to another area"),
        (OTHER, "Other, please specify"),
    ],
}
