# Generated by Django 3.2.13 on 2022-09-22 19:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_action_item", "0030_edcpermissions"),
    ]

    operations = [
        migrations.AlterField(
            model_name="actionitem",
            name="reference_model",
            field=models.CharField(
                help_text="model name in label_lower format", max_length=50, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="reference_model",
            field=models.CharField(
                help_text="model name in label_lower format", max_length=50, null=True
            ),
        ),
    ]
