# Generated by Django 3.0.4 on 2020-05-12 01:52

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_export", "0006_auto_20200512_0208"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="plan",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
            },
        ),
    ]
