# Generated by Django 5.1.2 on 2024-11-17 16:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0034_rename_display_label_assignment_display_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="container",
            name="max_per_subject",
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="historicalcontainer",
            name="max_per_subject",
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
    ]
