# Generated by Django 5.0.7 on 2024-08-12 16:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0007_qareportlog_edc_qarepor_accesse_738ffe_idx"),
    ]

    operations = [
        migrations.CreateModel(
            name="QaReportLogSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("username", models.CharField(max_length=100)),
                ("report_model", models.CharField(max_length=100)),
                ("first_accessed", models.DateTimeField()),
                ("last_accessed", models.DateTimeField()),
                ("access_count", models.IntegerField()),
            ],
            options={
                "verbose_name": "QA Report Log Summary",
                "verbose_name_plural": "QA Report Log Summary",
                "db_table": "qa_report_log_summary_view",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
    ]
