# Generated by Django 5.2.8 on 2025-11-13 05:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_export", "0024_alter_datarequest_revision_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="ExportReceipt",
        ),
        migrations.DeleteModel(
            name="FileHistory",
        ),
        migrations.RemoveField(
            model_name="historicalexportreceipt",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalfilehistory",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalobjecthistory",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalplan",
            name="history_user",
        ),
        migrations.DeleteModel(
            name="ObjectHistory",
        ),
        migrations.DeleteModel(
            name="Plan",
        ),
        migrations.DeleteModel(
            name="UploadExportReceiptFile",
        ),
        migrations.DeleteModel(
            name="HistoricalExportReceipt",
        ),
        migrations.DeleteModel(
            name="HistoricalFileHistory",
        ),
        migrations.DeleteModel(
            name="HistoricalObjectHistory",
        ),
        migrations.DeleteModel(
            name="HistoricalPlan",
        ),
    ]
