# Generated by Django 6.0 on 2026-01-14 15:00

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0095_auto_20260113_2005"),
    ]

    operations = []
