# Generated by Django 5.2.8 on 2025-11-20 23:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_metadata", "0035_crfmetadata_edc_metadata_crfmetadata_a4idx_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="requisitionmetadata",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": (
                    "subject_identifier",
                    "visit_code",
                    "visit_code_sequence",
                    "show_order",
                ),
                "verbose_name": "Requisition collection status",
                "verbose_name_plural": "Requisition collection status",
            },
        ),
        migrations.RemoveIndex(
            model_name="requisitionmetadata",
            name="edc_metadat_site_id_cc31cf_idx",
        ),
        migrations.RemoveIndex(
            model_name="requisitionmetadata",
            name="edc_metadat_subject_04cc77_idx",
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(
                fields=[
                    "subject_identifier",
                    "visit_code",
                    "visit_code_sequence",
                    "show_order",
                ],
                name="edc_metadat_subject_5a33a7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(fields=["site"], name="edc_metadat_site_id_eb923f_idx"),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(
                fields=["entry_status"], name="edc_metadat_entry_s_c6264a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(fields=["model"], name="edc_metadat_model_29f7e8_idx"),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(
                fields=["panel_name"], name="edc_metadat_panel_n_0de2e0_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(
                fields=["due_datetime"], name="edc_metadat_due_dat_8ac98a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="requisitionmetadata",
            index=models.Index(
                fields=["fill_datetime"], name="edc_metadat_fill_da_0dd40c_idx"
            ),
        ),
    ]
