# Generated by Django 4.2.7 on 2023-12-05 03:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_facility", "0011_remove_healthfacilitytypes_edc_facilit_name_78007a_idx"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="holiday",
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name="holiday",
            constraint=models.UniqueConstraint(
                fields=("country", "local_date"),
                name="edc_facility_holiday_country_uniq",
            ),
        ),
    ]
