# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
import edc_model.validators.date
import edc_protocol.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_visit_schedule",
            "0019_alter_historicalonschedule_device_created_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalonschedule",
            name="onschedule_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
            ),
        ),
        migrations.AlterField(
            model_name="offschedule",
            name="offschedule_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Date and time subject taken off schedule",
            ),
        ),
        migrations.AlterField(
            model_name="onschedule",
            name="onschedule_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectschedulehistory",
            name="schedule_status",
            field=models.CharField(
                choices=[
                    ("onschedule", "On schedule"),
                    ("offschedule", "Off schedule"),
                ],
                default="",
                max_length=15,
            ),
        ),
    ]
