{% extends edc_base_template %}
{% load static %}
{% load edc_label_extras %}

{% block extra-styles %}
{{ block.super }}
    {# <script type="text/javascript" charset="utf8" src="{% static 'edc_label/js/BrowserPrint-1.0.4.min.js' %}"></script> #}
{% endblock extra-styles %}

{% block main %}


 <div class="container">

    <div class="panel-group">

    <div class="panel panel-success">
      <div class="panel-heading"><h4>Your print server</h4></div>
      <div class="panel-body">
      <form action="{% url 'edc_label:change_session_print_server' %}" method="post">
          {% csrf_token %}
        <div class="form-group">
              <select class="form-control" id="{{ PRINT_SERVER_NAME }}" name="{{ PRINT_SERVER_NAME }}" onchange="submit();">
              <option {% if not selected_print_server_name %}selected{% endif %} value="--">select one</option>
              {% for print_server_name in print_servers.keys %}
                 <option {% if print_server_name == selected_print_server_name %}selected{% endif %}>{{ print_server_name }}</option>
              {% endfor %}
            </select>
        </div>
      </form>
      </div>
      </div>


  {% if printers %}

      {% printer_config heading="Your clinic label printer" printer_type=CLINIC_LABEL_PRINTER selected_printer=selected_clinic_label_printer printers=printers %}

      {% printer_config heading="Your lab label printer" printer_type=LAB_LABEL_PRINTER selected_printer=selected_lab_label_printer printers=printers %}

  {% endif %}

  </div>
</div> <!-- container -->
{% endblock main %}
