CHART = "chart"
COMPLETED_PROTOCOL_VISIT = "completed protocol"
DEFERRED_VISIT = "deferred"
LOST_VISIT = "lost"
MISSED_VISIT = "missed"
SCHEDULED = "scheduled"
UNSCHEDULED = "unscheduled"
NO_FOLLOW_UP_REASONS = [
    LOST_VISIT,
    DEFERRED_VISIT,
    COMPLETED_PROTOCOL_VISIT,
]
FOLLOW_UP_REASONS = [SCHEDULED, UNSCHEDULED, MISSED_VISIT]
REQUIRED_REASONS = NO_FOLLOW_UP_REASONS + FOLLOW_UP_REASONS
VISIT_MISSED_ACTION = "submit_visit_missed"
