# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-05 19:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_lab", "0005_auto_20170305_2109")]

    operations = [
        migrations.AddField(
            model_name="aliquot",
            name="shipped",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicalaliquot",
            name="shipped",
            field=models.BooleanField(default=False),
        ),
    ]
