# Generated by Django 4.2.7 on 2023-11-28 03:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_metadata", "0025_crfmetadata_document_user_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="crfmetadata",
            old_name="model_verbose_name",
            new_name="document_name",
        ),
        migrations.RenameField(
            model_name="requisitionmetadata",
            old_name="model_verbose_name",
            new_name="document_name",
        ),
    ]
