# Generated by Django 5.2.3 on 2025-06-27 13:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0072_stockout_bins"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="stockout",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "verbose_name": "Stock availability",
                "verbose_name_plural": "Stock availability",
            },
        ),
    ]
