# Generated by Django 4.2.11 on 2024-06-19 01:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0006_qareportlog"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="qareportlog",
            index=models.Index(fields=["accessed"], name="edc_qarepor_accesse_738ffe_idx"),
        ),
    ]
