# Generated by Django 5.2.8 on 2025-11-20 23:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_metadata", "0034_alter_crfmetadata_options"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(
                fields=["due_datetime"], name="edc_metadata_crfmetadata_a4idx"
            ),
        ),
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(
                fields=["fill_datetime"], name="edc_metadata_crfmetadata_a5idx"
            ),
        ),
    ]
