# Generated by Django 4.0.4 on 2022-05-12 23:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0021_auto_20210929_2343"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dataquery",
            name="recipients",
            field=models.ManyToManyField(
                blank=True,
                help_text="Select any additional recipients. Users in the `Site Data Manager` group are automatically included.",
                related_name="+",
                to="edc_data_manager.queryuser",
                verbose_name="Sent to",
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="data_dictionaries",
            field=models.ManyToManyField(
                blank=True,
                help_text="select all that apply",
                related_name="+",
                to="edc_data_manager.crfdatadictionary",
                verbose_name="Question(s)",
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="recipients",
            field=models.ManyToManyField(
                blank=True,
                help_text="Select any additional recipients. Users in the `Site Data Manager` group are automatically included.",
                related_name="+",
                to="edc_data_manager.queryuser",
                verbose_name="Send to",
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="visit_schedule",
            field=models.ManyToManyField(
                blank=True,
                help_text="select all that apply",
                related_name="+",
                to="edc_data_manager.queryvisitschedule",
                verbose_name="Visit",
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="visit_schedule_exclude",
            field=models.ManyToManyField(
                blank=True,
                help_text="select all that apply",
                related_name="+",
                to="edc_data_manager.queryvisitschedule",
                verbose_name="Visit (exclude)",
            ),
        ),
    ]
