# Generated by Django 5.2.4 on 2025-09-10 03:24

import django_revision.revision_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_lab", "0034_alter_aliquot_site_alter_box_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aliquot",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="box",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="boxitem",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="boxtype",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="consignee",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaliquot",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbox",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalboxitem",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconsignee",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmanifest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalorder",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalresult",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalresultitem",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalshipper",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="manifest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="manifestitem",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="panel",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="result",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="resultitem",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="shipper",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
    ]
