# Generated by Django 5.2.7 on 2025-10-24 04:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_data_manager", "0042_alter_datadictionary_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalqueryrule",
            name="comment",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalqueryrule",
            name="query_text",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Generic query text for auto-generated queries.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqueryrule",
            name="reference_model",
            field=models.CharField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="comment",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="query_text",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Generic query text for auto-generated queries.",
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="reference_model",
            field=models.CharField(default="", editable=False, max_length=150),
        ),
    ]
