{% extends "admin/change_list.html" %}
{% load i18n admin_urls static admin_list edc_admin_modify %}

{% block extrahead %}{{ block.super }}
<!-- begin edc_model extrahead -->
  <meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<script src="{% static 'fontawesomefree/js/all.min.js' %}"></script>
<!-- end edc_model extrahead -->
{% endblock %}

{% block extrastyle %}{{ block.super }}
{%  for css in edc_model_admin_css_theme_path %}
<link rel='stylesheet' type="text/css" href='{% static css %}'>
{% endfor %}
{% endblock %}

{% block dark-mode-vars %}
<link rel="stylesheet" type="text/css" href="{% static 'edc_model_admin/css/dark_mode.css' %}">
{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block branding %}{% show_navbar_for_admin_templates_b3 %}&nbsp;{% if app_url %}<a href="{{ app_url }}">{{ opts.app_config.verbose_name|capfirst }}</A>{% else %}{{ opts.app_config.verbose_name|capfirst }}{% endif %}&nbsp;&rsaquo;&nbsp;{{ opts.verbose_name|capfirst|truncatechars:25 }}{% endblock %}

{% block welcome-msg %}{% endblock %}

{% block userlinks %}{% logout_row %}{% endblock %}

{% block object-tools %}
<ul class="object-tools">
{% block object-tools-items %}{% if show_object_tools %}{% change_list_object_tools %}{% endif %}{% endblock %}
</ul>
{% if change_list_note %}<h5><span style="color:orange;">Note:</span></h5><p style="width:80%">{{ change_list_note }}</p>{% endif %}
{% endblock %}

{% block pagination %}{{ block.super }}{% if change_list_help %}<p style="width:80%">{{ change_list_help }}</p>{% endif %}{% endblock %}

{% block content %}{{ block.super }}{% revision_row %}{% endblock content %}
