# Generated by Django 5.2.6 on 2025-09-17 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_action_item",
            "0038_alter_actionitem_revision_alter_actiontype_revision_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="actionitem",
            name="auto_created_comment",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="instructions",
            field=models.TextField(
                blank=True, default="", help_text="populated by action class"
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="May be left blank. e.g. action identifier from reference model that opened the item (parent).",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="priority",
            field=models.CharField(
                blank=True,
                choices=[
                    ("high", "High Priority"),
                    ("medium", "Medium Priority"),
                    ("low", "Low Priority"),
                ],
                default="",
                help_text="Leave blank to use default for this action type.",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="actionitem",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="May be left blank. e.g. action identifier from source model that opened the item.",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="instructions",
            field=models.TextField(blank=True, default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="reference_model",
            field=models.CharField(
                blank=True, default="", help_text="reference model", max_length=100
            ),
        ),
        migrations.AlterField(
            model_name="actiontype",
            name="related_reference_model",
            field=models.CharField(
                blank=True,
                default="",
                help_text="origin reference model",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="edcpermissions",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="edcpermissions",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="edcpermissions",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="edcpermissions",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="auto_created_comment",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="instructions",
            field=models.TextField(
                blank=True, default="", help_text="populated by action class"
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="May be left blank. e.g. action identifier from reference model that opened the item (parent).",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="priority",
            field=models.CharField(
                blank=True,
                choices=[
                    ("high", "High Priority"),
                    ("medium", "Medium Priority"),
                    ("low", "Low Priority"),
                ],
                default="",
                help_text="Leave blank to use default for this action type.",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="May be left blank. e.g. action identifier from source model that opened the item.",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalreference",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="reference",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="reference",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
    ]
