# Generated by Django 5.0.7 on 2024-08-12 16:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0009_auto_20240812_1918"),
    ]

    operations = []
