# Generated by Django 6.0 on 2026-01-18 17:12

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0099_historicalstock_confirmed_at_location_and_more"),
    ]

    operations = []
