# Generated by Django 5.1.2 on 2024-11-17 19:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0035_container_max_per_subject_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstock",
            name="confirmed_at_site",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicalstock",
            name="confirmed_at_site_by",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name="historicalstock",
            name="confirmed_at_site_datetime",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="stock",
            name="confirmed_at_site",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="stock",
            name="confirmed_at_site_by",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name="stock",
            name="confirmed_at_site_datetime",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="confirmed_by",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name="stock",
            name="confirmed_by",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
    ]
