# Generated by Django 4.2.1 on 2023-07-05 02:16

import django.db.models.manager
from django.db import migrations

import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0027_alter_dataquery_dm_user"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dataquery",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Data Query",
                "verbose_name_plural": "Data Queries",
            },
        ),
        migrations.AlterModelOptions(
            name="queryrule",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("title",),
                "verbose_name": "Query Rule",
                "verbose_name_plural": "Query Rules",
            },
        ),
        migrations.AlterModelManagers(
            name="dataquery",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]
