{% extends edc_lab_listboard_template %}


{% block panel_action_buttons %}

    <a href="{{ new_manifest.href }}" role="button" class="btn btn-sm btn-default" />New manifest</a>
    <button type="submit" class="btn btn-default btn-sm" id="action" name="action" value="remove_selected_items" form="{{ form_action_name }}">
         <span class="text text-danger"><i class="fas fa-window-close fa-sm"></i></span> &nbsp;Remove selected
    </button>

        <button class="btn btn-sm btn-default" type="submit" id="action" name="action" form="{{ form_action_name }}" value="print_labels">
           <i class="fas fa-barcode fa-sm"></i> Print labels
        </button>
        <button class="btn btn-sm btn-default" type="submit" id="action" name="action" form="{{ form_action_name }}" value="ship_selected_items">
           <i class="fas fa-ship fa-sm"></i> Ship selected
        </button>

{% endblock panel_action_buttons %}

{% block results_header %}
    {% include 'edc_lab_dashboard/listboard/manifest/results_header.html' %}
{% endblock results_header %}

{% block results_body %}
    {% include 'edc_lab_dashboard/listboard/manifest/results_body.html' %}
{% endblock results_body %}
