from .age import AgeTable
from .art import ArtTable
from .bmi import BmiTable
from .bp import BpTable
from .fasting import FastingTable
from .fbg import FbgTable
from .fbg_ogtt import FbgOgttTable
from .gender import GenderTable
from .hba1c import HbA1cTable
from .ogtt import OgttTable
from .waist import WaistCircumferenceTable
