<a style="white-space: nowrap;background-color:darkgray;color: black" {% if changelist_url %}title="Go TMG reports"{% endif %} class="button" {% if changelist_url %}href="{{ changelist_url }}?q={{ subject_identifier }}"{% else %} disabled {% endif %}>TMG</a>
