# Generated by Django 5.2.8 on 2025-11-20 22:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_metadata", "0032_alter_crfmetadata_revision_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="crfmetadata",
            name="edc_metadat_site_id_d3b213_idx",
        ),
        migrations.RemoveIndex(
            model_name="crfmetadata",
            name="edc_metadat_subject_dd4400_idx",
        ),
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(
                fields=[
                    "subject_identifier",
                    "visit_code",
                    "visit_code_sequence",
                    "show_order",
                ],
                name="edc_metadata_crfmetadata_a0idx",
            ),
        ),
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(fields=["site"], name="edc_metadata_crfmetadata_a1idx"),
        ),
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(
                fields=["entry_status"], name="edc_metadata_crfmetadata_a2idx"
            ),
        ),
        migrations.AddIndex(
            model_name="crfmetadata",
            index=models.Index(fields=["model"], name="edc_metadata_crfmetadata_a3idx"),
        ),
    ]
