# Generated by Django 6.0 on 2026-01-19 16:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0101_rename_stored_at_site_historicalstock_stored_at_location_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="dispenseitem",
            name="code",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                max_length=15,
                verbose_name="Stock code",
            ),
        ),
        migrations.AddField(
            model_name="historicaldispenseitem",
            name="code",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                max_length=15,
                verbose_name="Stock code",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="stored_at_location",
            field=models.BooleanField(default=False, help_text="See storagebinitem."),
        ),
        migrations.AlterField(
            model_name="historicalstocktransfer",
            name="item_count",
            field=models.PositiveIntegerField(
                help_text="Suggested item count", null=True
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="stored_at_location",
            field=models.BooleanField(default=False, help_text="See storagebinitem."),
        ),
        migrations.AlterField(
            model_name="stocktransfer",
            name="item_count",
            field=models.PositiveIntegerField(
                help_text="Suggested item count", null=True
            ),
        ),
    ]
