# Generated by Django 3.2.7 on 2021-09-29 20:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0020_auto_20210921_0403"),
    ]

    operations = [
        migrations.AddField(
            model_name="dataquery",
            name="auto_resolved",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="dataquery",
            name="missed_visit",
            field=models.BooleanField(
                default=False,
                help_text="If visit/timepoint was missed, data is not expected",
                verbose_name="Visit reported as missed",
            ),
        ),
        migrations.AddField(
            model_name="historicaldataquery",
            name="auto_resolved",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="historicaldataquery",
            name="missed_visit",
            field=models.BooleanField(
                default=False,
                help_text="If visit/timepoint was missed, data is not expected",
                verbose_name="Visit reported as missed",
            ),
        ),
    ]
