# Generated by Django 4.2.6 on 2024-03-01 10:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_locator", "0036_alter_historicalsubjectlocator_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="consent_model",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="consent_version",
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="consent_model",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="consent_version",
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
    ]
