{% extends edc_base_template %}

{% load static %}

{% block main %}

  <div class="container">
    <div class="col-sm-12">
      <h4>Edc research data system for {{ project_name }}</h4>
      <h6>Revision {{ revision }}</h6>
      <p>
      <B>The use of this system is strictly for research purposes only and specifically for the {{ project_name }} trial.</B>
      <BR>The source code for this system is published under the <a href="https://www.gnu.org/licenses/gpl-3.0.en.html">{{ license }}</a>.
      <BR>Source code for the EDC general modules is available at <a target="_blank" href="http://github.com/clinicedc/?q={{project_name|lower}}">http://github.com/clinicedc/</a>.
      <BR>Source code for modules developed specifically for the {{ project_name }} trial are available at <a target="_blank" href="{{project_repo}}">{{ project_repo }}</a>.

      <BR><BR>All other third party packages and modules used are provided according their specific licenses.

    </p>
    </div>
    <div class="col-sm-12">
      <ul class="nav nav-pills">
        <li class="active"><a data-toggle="pill" href="#third_party_packages">Packages</a></li>
        <li><a data-toggle="pill" href="#installed_apps">Installed Apps</a></li>
        <li><a data-toggle="pill" href="#edc_packages">Develop</a></li>

        <div class="tab-content">
          <div id="third_party_packages" class="tab-pane fade in active">
            <table class="table table-hover responsive">
            <thead>
                <tr><th>#</th><th>Packages</th></tr>
            </thead>
            <tbody>
              {% for package in  third_party_packages %}
                <tr><td>{{ forloop.counter }}</td><td>{{ package }}</td></tr>
              {% endfor %}
            </tbody>
            </table>
          </div>

          <div id="installed_apps" class="tab-pane fade in">
            <table class="table table-hover responsive">
            <thead>
                <tr><th>#</th><th>Installed Apps</th></tr>
            </thead>
            <tbody>
              {% for app in installed_apps %}
                <tr><th>#</th><td>{{ app }}</td></tr>
              {% endfor %}
            </tbody>
            </table>
          </div>

          <div id="edc_packages" class="tab-pane fade in">
            <table class="table table-hover responsive">
            <thead>
                <tr><th>#</th><th name='edc_packages'>Develop</th></tr>
            </thead>
            <tbody>
              {% for package in  edc_packages %}
                <tr><td>{{ forloop.counter }}</td><td>{{ package }}</td></tr>
              {% endfor %}
            </tbody>
            </table>
          </div>



        </div>
      </ul>
    </div>
  </div>
{% endblock main %}
