# Generated by Django 5.1.2 on 2024-11-11 14:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pylabels", "0008_labelconfiguration_requires_allocated"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="labelconfiguration",
            name="requires_allocated",
        ),
        migrations.AddField(
            model_name="labelconfiguration",
            name="requires_allocation",
            field=models.BooleanField(default=False, verbose_name="Is a subject label"),
        ),
    ]
