# Generated by Django 3.2.13 on 2022-09-29 14:42

from django.db import migrations, models

import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0015_auto_20220913_2139"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="product",
            managers=[
                ("objects", models.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="stock",
            managers=[
                ("objects", models.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]
