# Generated by Django 5.1.2 on 2024-11-15 04:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0025_alter_stock_receive_item"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstockrequest",
            name="cutoff_datetime",
            field=models.DateTimeField(
                blank=True, default=None, help_text="May be left blank", null=True
            ),
        ),
        migrations.AddField(
            model_name="stockrequest",
            name="cutoff_datetime",
            field=models.DateTimeField(
                blank=True, default=None, help_text="May be left blank", null=True
            ),
        ),
    ]
