{%  load i18n %}
<H5><B><span style="color:orange;">Interviewer to read</span></B></H5>
<p>{%  trans "Drag the slider on the line below at the point showing your best guess about how much study medication you have taken in the last 14 days or in the last 28 days as appropriate:" %}
  <BR><BR>
  <B>0%</B> {% trans "means you have taken no study pills" %}<BR>
  <B>50%</B> {% trans "means you have taken half of your study pills" %}<BR>
  <B>100%</B> {% trans "means you have taken all your study pills" %}<BR>
</p>
