{% load i18n %}
<a href="{{ url }}"
   role="button" class="btn btn-sm btn-primary" data-toggle="tooltip" title="{% trans "Go to subject's schedule" %}">
<i class="fa-solid fa-reply fa-1x fa-fw" aria-hidden="true"></i>
  {% trans "Schedule" %}
</a>
