# Generated by Django 5.2.4 on 2025-09-10 03:24

import django_revision.revision_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_sites", "0008_delete_edcsite_remove_siteprofile_description"),
    ]

    operations = [
        migrations.AlterField(
            model_name="edcpermissions",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                null=True,
                verbose_name="Revision",
            ),
        ),
    ]
