# Generated by Django 4.2.7 on 2023-12-05 20:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0034_issue"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="datadictionary",
            index=models.Index(
                fields=["model", "number", "prompt"],
                name="edc_data_ma_model_92b469_idx",
            ),
        ),
    ]
