account_manager = [
    "auth.add_user",
    "auth.change_permission",
    "auth.change_user",
    "auth.delete_permission",
    "auth.delete_user",
    "auth.view_group",
    "auth.view_permission",
    "auth.view_user",
    "edc_auth.add_userprofile",
    "edc_auth.change_userprofile",
    "edc_auth.delete_userprofile",
    "edc_auth.view_userprofile",
    "edc_auth.add_role",
    "edc_auth.change_role",
    "edc_auth.delete_role",
    "edc_auth.view_role",
]
