# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_refusal", "0008_alter_historicalsubjectrefusal_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="refusalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Refusal Reason",
                "verbose_name_plural": "Refusal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectrefusal",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Refusal",
                "verbose_name_plural": "Subject Refusals",
            },
        ),
        migrations.RemoveIndex(
            model_name="refusalreasons",
            name="edc_refusal_id_be47bd_idx",
        ),
        migrations.AddField(
            model_name="historicalsubjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="refusalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_refusal_display_22b812_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrefusal",
            index=models.Index(
                fields=["modified", "created"], name="edc_refusal_modifie_49a6c8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrefusal",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_refusal_user_mo_a67c8d_idx",
            ),
        ),
    ]
