# Generated by Django 4.2.11 on 2024-06-17 22:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("edc_qareports", "0001_initial"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="ReportNote",
            new_name="QaReportNote",
        ),
        migrations.RemoveConstraint(
            model_name="qareportnote",
            name="edc_qareports_reportnote_name_subj_uniq",
        ),
        migrations.RenameIndex(
            model_name="qareportnote",
            new_name="edc_qarepor_modifie_5f102f_idx",
            old_name="edc_qarepor_modifie_fd8974_idx",
        ),
        migrations.RenameIndex(
            model_name="qareportnote",
            new_name="edc_qarepor_user_mo_6166bf_idx",
            old_name="edc_qarepor_user_mo_9875e1_idx",
        ),
        migrations.AddConstraint(
            model_name="qareportnote",
            constraint=models.UniqueConstraint(
                fields=("report_model", "subject_identifier"),
                name="edc_qareports_qareportnote_name_subj_uniq",
            ),
        ),
    ]
