from .autocomplete_admin import SiteProxyAdmin, VisitScheduleAdmin
from .medication import (
    AssignmentAdmin,
    DosageGuidelineAdmin,
    FormulationAdmin,
    FormulationTypeAdmin,
    FrequencyUnitsAdmin,
    MedicationAdmin,
    RouteAdmin,
    UnitsAdmin,
)
from .prescription import RxAdmin, RxRefillAdmin
from .reports import StockAvailabilityModelAdmin
from .scan_duplicates_admin import ScanDuplicatesAdmin
from .stock import (
    AllocationAdmin,
    AllocationProxyAdmin,
    ConfirmationAdmin,
    ConfirmationAtLocationHistoryAdmin,
    ConfirmationAtLocationItemHistoryAdmin,
    ContainerAdmin,
    ContainerTypeAdmin,
    DispenseAdmin,
    DispenseItemAdmin,
    LocationAdmin,
    LotAdmin,
    OrderAdmin,
    OrderItemAdmin,
    ProductAdmin,
    ReceiveAdmin,
    ReceiveItemAdmin,
    RequestRepackAdmin,
    StockAdmin,
    StockProxyAdmin,
    StockRequestAdmin,
    StockRequestItemAdmin,
    StockTransferAdmin,
    StorageBinAdmin,
    StorageBinItemAdmin,
    SupplierAdmin,
)
