# Generated by Django 6.0 on 2026-01-19 00:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0100_auto_20260118_2012"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalstock",
            old_name="stored_at_site",
            new_name="stored_at_location",
        ),
        migrations.RenameField(
            model_name="stock",
            old_name="stored_at_site",
            new_name="stored_at_location",
        ),
    ]
