# Generated by Django 5.1.2 on 2024-11-17 14:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0032_historicalstockrequest_task_id_stockrequest_task_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="container",
            name="display_name",
            field=models.CharField(blank=True, max_length=100, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="historicalcontainer",
            name="display_name",
            field=models.CharField(blank=True, db_index=True, max_length=100, null=True),
        ),
    ]
