# Generated by Django 3.0.6 on 2020-07-29 20:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_crf", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="crfstatus",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "CRF Status",
                "verbose_name_plural": "CRF Status",
            },
        ),
    ]
