# Generated by Django 5.0 on 2023-12-13 14:26

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_sites", "0007_edcpermissions"),
    ]

    operations = [
        migrations.DeleteModel(
            name="EdcSite",
        ),
        migrations.RemoveField(
            model_name="siteprofile",
            name="description",
        ),
    ]
