# Generated by Django 5.1.2 on 2024-11-17 14:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0033_container_display_name_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="assignment",
            old_name="display_label",
            new_name="display_name",
        ),
        migrations.RenameField(
            model_name="historicalassignment",
            old_name="display_label",
            new_name="display_name",
        ),
    ]
